==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/plbuf_8c.js <==
var plbuf_8c =
[
    [ "_color_map", "struct__color__map.html", "struct__color__map" ],
    [ "_state", "struct__state.html", "struct__state" ],
    [ "NEED_PLDEBUG", "plbuf_8c.html#ad92ef941bb38ab1d2af3bce830fd47c9", null ],
    [ "plbuf_bop", "plbuf_8c.html#adfc99508e469151cb842952453510157", null ],
    [ "plbuf_control", "plbuf_8c.html#ae13af7090f100c2b0eec7d68a35ca5c9", null ],
    [ "plbuf_eop", "plbuf_8c.html#a046684abbeeaa297d5a74c9d98f2a5b1", null ],
    [ "plbuf_esc", "plbuf_8c.html#aab238e02e3073b5814304c7e88a4bdd9", null ],
    [ "plbuf_fill", "plbuf_8c.html#a186cd16c34b5692fb12e20baa91a1d38", null ],
    [ "plbuf_image", "plbuf_8c.html#a7224eaff557443e8ff7d9d2500b60faf", null ],
    [ "plbuf_init", "plbuf_8c.html#aea9c63247a3f241d4696751d99d82504", null ],
    [ "plbuf_line", "plbuf_8c.html#acda7b457e0bcc02b12962c4e649c886d", null ],
    [ "plbuf_polyline", "plbuf_8c.html#a8d70a964a7060d75b7a110394dacaae2", null ],
    [ "plbuf_restore", "plbuf_8c.html#a6a803f5f96628d3fd4c7e94bea77ac7d", null ],
    [ "plbuf_save", "plbuf_8c.html#ad0cbddcf799e4ae1409ff51a08574505", null ],
    [ "plbuf_state", "plbuf_8c.html#a4a253a79cedb8150e1dd1e918b22240c", null ],
    [ "plbuf_swin", "plbuf_8c.html#a63c9939a28a2bfdfa4747fb4c264cb0b", null ],
    [ "plbuf_switch", "plbuf_8c.html#a0e9c9744efe48e75eba3bc63b1ba4fa5", null ],
    [ "plbuf_text", "plbuf_8c.html#a34c0b51e095c370e72f50a46936d95f9", null ],
    [ "plbuf_text_unicode", "plbuf_8c.html#acd1c2d16c67fffbc2c1d6534db34e542", null ],
    [ "plbuf_tidy", "plbuf_8c.html#a755bbbb00c68d8438779839631281dd1", null ],
    [ "plRemakePlot", "plbuf_8c.html#aca5d2d062ebdac7da80ab50841578e4d", null ],
    [ "rd_command", "plbuf_8c.html#afe25464ef6eee65400e6cc414e1a8bef", null ],
    [ "rd_data", "plbuf_8c.html#a242010916ecbf0311b25cb53dd279131", null ],
    [ "rdbuf_bop", "plbuf_8c.html#aad64e647b7f7b3af09f3c62842c4f7c8", null ],
    [ "rdbuf_eop", "plbuf_8c.html#a209868297bfb200c84cbfe90ba08f0e0", null ],
    [ "rdbuf_eop", "plbuf_8c.html#ad7ca15074bcfb34b7be34e84f2ef4c9a", null ],
    [ "rdbuf_esc", "plbuf_8c.html#ae88980d2f7d522656c5950ddd56196dd", null ],
    [ "rdbuf_fill", "plbuf_8c.html#aad07e02f2e79a2c170853e8aa4e6b2f9", null ],
    [ "rdbuf_image", "plbuf_8c.html#aea9f032aa713660a5dc4c9977eaa61dd", null ],
    [ "rdbuf_init", "plbuf_8c.html#a8db7bde63185bde9dc11e067032d72ca", null ],
    [ "rdbuf_init", "plbuf_8c.html#ada55e60d5d9707c8b9422473cb15b370", null ],
    [ "rdbuf_line", "plbuf_8c.html#a7bec22c9791616b92153645c10edbc36", null ],
    [ "rdbuf_polyline", "plbuf_8c.html#a5cc6b30bbe75730cde65b3a2ba00b084", null ],
    [ "rdbuf_state", "plbuf_8c.html#ad9ba8fe84be30902c7d521c076a91456", null ],
    [ "rdbuf_swin", "plbuf_8c.html#a2bc6f17b2d907b6785d6c898b45bb064", null ],
    [ "rdbuf_text", "plbuf_8c.html#afa641052a2e12eb594108a56d6eaa710", null ],
    [ "rdbuf_text_unicode", "plbuf_8c.html#a6e3e586984481314f86de46295eea6f7", null ],
    [ "wr_command", "plbuf_8c.html#af4896eb58fe07c91ea761a8a360ba06a", null ],
    [ "wr_data", "plbuf_8c.html#ad513629816f783d949b03054d3a78872", null ]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/plbuf_8c.js <==
var plbuf_8c =
[
    [ "_state", "struct__state.html", "struct__state" ],
    [ "NEED_PLDEBUG", "plbuf_8c.html#ad92ef941bb38ab1d2af3bce830fd47c9", null ],
    [ "check_buffer_size", "plbuf_8c.html#a9af620a524d127e66e68dedf7f6bd89d", null ],
    [ "plbuf_bop", "plbuf_8c.html#adfc99508e469151cb842952453510157", null ],
    [ "plbuf_clip", "plbuf_8c.html#a158a461e9a9bf8ca6e47ad8a9b5cd550", null ],
    [ "plbuf_control", "plbuf_8c.html#ae13af7090f100c2b0eec7d68a35ca5c9", null ],
    [ "plbuf_di", "plbuf_8c.html#ab41c997275bfc69fa15fac8e149944e8", null ],
    [ "plbuf_eop", "plbuf_8c.html#a0e4f86ffd4f5aacfb07645ca87344671", null ],
    [ "plbuf_esc", "plbuf_8c.html#aab238e02e3073b5814304c7e88a4bdd9", null ],
    [ "plbuf_fill", "plbuf_8c.html#a186cd16c34b5692fb12e20baa91a1d38", null ],
    [ "plbuf_image", "plbuf_8c.html#a7224eaff557443e8ff7d9d2500b60faf", null ],
    [ "plbuf_init", "plbuf_8c.html#aea9c63247a3f241d4696751d99d82504", null ],
    [ "plbuf_line", "plbuf_8c.html#acda7b457e0bcc02b12962c4e649c886d", null ],
    [ "plbuf_polyline", "plbuf_8c.html#a8d70a964a7060d75b7a110394dacaae2", null ],
    [ "plbuf_restore", "plbuf_8c.html#a6a803f5f96628d3fd4c7e94bea77ac7d", null ],
    [ "plbuf_save", "plbuf_8c.html#ad0cbddcf799e4ae1409ff51a08574505", null ],
    [ "plbuf_setsub", "plbuf_8c.html#a160881830ff1593be6c566eda90e9371", null ],
    [ "plbuf_ssub", "plbuf_8c.html#aea49ec83e7db34f8158a268d0735b8e1", null ],
    [ "plbuf_state", "plbuf_8c.html#a4a253a79cedb8150e1dd1e918b22240c", null ],
    [ "plbuf_swin", "plbuf_8c.html#a63c9939a28a2bfdfa4747fb4c264cb0b", null ],
    [ "plbuf_switch", "plbuf_8c.html#a0e9c9744efe48e75eba3bc63b1ba4fa5", null ],
    [ "plbuf_text", "plbuf_8c.html#a34c0b51e095c370e72f50a46936d95f9", null ],
    [ "plbuf_text_unicode", "plbuf_8c.html#acd1c2d16c67fffbc2c1d6534db34e542", null ],
    [ "plbuf_tidy", "plbuf_8c.html#a755bbbb00c68d8438779839631281dd1", null ],
    [ "plbuf_write", "plbuf_8c.html#af5320f9a99b1bd05f7e19c7cac91ee72", null ],
    [ "plFlushBuffer", "plbuf_8c.html#a3356f1609c863412f0ef0c9519249011", null ],
    [ "plRemakePlot", "plbuf_8c.html#aca5d2d062ebdac7da80ab50841578e4d", null ],
    [ "rd_command", "plbuf_8c.html#afe25464ef6eee65400e6cc414e1a8bef", null ],
    [ "rd_data", "plbuf_8c.html#a242010916ecbf0311b25cb53dd279131", null ],
    [ "rd_data_no_copy", "plbuf_8c.html#a69e3c6f1b472a4be33d88f73d270cbea", null ],
    [ "rdbuf_bop", "plbuf_8c.html#aad64e647b7f7b3af09f3c62842c4f7c8", null ],
    [ "rdbuf_clip", "plbuf_8c.html#a03098c55de5a88d538fb8da01d6172a7", null ],
    [ "rdbuf_di", "plbuf_8c.html#a438ab9b1261eaecaa968f895d4569ffb", null ],
    [ "rdbuf_eop", "plbuf_8c.html#a209868297bfb200c84cbfe90ba08f0e0", null ],
    [ "rdbuf_eop", "plbuf_8c.html#ad7ca15074bcfb34b7be34e84f2ef4c9a", null ],
    [ "rdbuf_esc", "plbuf_8c.html#ae88980d2f7d522656c5950ddd56196dd", null ],
    [ "rdbuf_fill", "plbuf_8c.html#aad07e02f2e79a2c170853e8aa4e6b2f9", null ],
    [ "rdbuf_image", "plbuf_8c.html#aea9f032aa713660a5dc4c9977eaa61dd", null ],
    [ "rdbuf_init", "plbuf_8c.html#a8db7bde63185bde9dc11e067032d72ca", null ],
    [ "rdbuf_init", "plbuf_8c.html#ada55e60d5d9707c8b9422473cb15b370", null ],
    [ "rdbuf_line", "plbuf_8c.html#a7bec22c9791616b92153645c10edbc36", null ],
    [ "rdbuf_polyline", "plbuf_8c.html#a5cc6b30bbe75730cde65b3a2ba00b084", null ],
    [ "rdbuf_setsub", "plbuf_8c.html#ad1f778ddc28bcfe4d0e4c6745c81c068", null ],
    [ "rdbuf_ssub", "plbuf_8c.html#a95949f6bffdb4d28fda6fe00691dca8d", null ],
    [ "rdbuf_state", "plbuf_8c.html#ad9ba8fe84be30902c7d521c076a91456", null ],
    [ "rdbuf_swin", "plbuf_8c.html#a2bc6f17b2d907b6785d6c898b45bb064", null ],
    [ "rdbuf_text", "plbuf_8c.html#afa641052a2e12eb594108a56d6eaa710", null ],
    [ "rdbuf_text_unicode", "plbuf_8c.html#a6e3e586984481314f86de46295eea6f7", null ],
    [ "wr_command", "plbuf_8c.html#af4896eb58fe07c91ea761a8a360ba06a", null ],
    [ "wr_data", "plbuf_8c.html#ad513629816f783d949b03054d3a78872", null ]
];
